@@ -37,6 +37,7 @@ from collections import Counter
 from pm4pydistr.master.session_checker import SessionChecker
 from pm4pydistr.configuration import DEFAULT_WINDOW_SIZE
 from pm4py.util import points_subset
+from pm4py.objects.log.util import xes
 import time
 import sys
 
@@ -197,6 +198,9 @@ class Master:
 
             overall_dfg = overall_dfg + Counter(thread.content['dfg'])
 
+        for el in overall_dfg:
+            overall_dfg[el] = overall_dfg[el] / len(threads)
+
         return overall_dfg
 
     def calculate_composite_obj(self, session, process, use_transition, no_samples, attribute_key,
@@ -247,6 +251,8 @@ class Master:
         overall_obj["end_activities"] = dict(overall_obj["end_activities"])
         overall_obj["frequency_dfg"] = dict(overall_obj["frequency_dfg"])
         if performance_required:
+            for el in overall_obj["performance_dfg"]:
+                overall_obj["performance_dfg"][el] = overall_obj["performance_dfg"][el] / len(threads)
             overall_obj["performance_dfg"] = dict(overall_obj["performance_dfg"])
 
         return overall_obj
@@ -525,7 +531,7 @@ class Master:
 
         return ret
 
-    def get_events_per_time(self, session, process, use_transition, no_samples, max_ret_items=100000):
+    def get_events_per_time(self, session, process, use_transition, no_samples, max_ret_items=100000, timestamp_key=xes.DEFAULT_TIMESTAMP_KEY):
         all_slaves = list(self.slaves.keys())
 
         threads = []
@@ -537,6 +543,7 @@ class Master:
 
             m = EventsPerTimeRequest(session, slave_host, slave_port, use_transition, no_samples, process)
             m.max_ret_items = max_ret_items
+            m.timestamp_key = timestamp_key
 
             m.start()
 
