@@ -597,6 +597,7 @@ def get_events_per_time():
         use_transition = request.args.get(PARAMETER_USE_TRANSITION, type=str, default=str(DEFAULT_USE_TRANSITION))
         no_samples = request.args.get(PARAMETER_NO_SAMPLES, type=int, default=DEFAULT_MAX_NO_SAMPLES)
         max_no_ret_items = request.args.get(PARAMETER_NUM_RET_ITEMS, type=int, default=100000)
+        timestamp_key = request.args.get('timestamp_key', type=str, default=xes.DEFAULT_TIMESTAMP_KEY)
 
         if use_transition == "True":
             use_transition = True
@@ -611,6 +612,7 @@ def get_events_per_time():
             parameters[PARAMETER_NO_SAMPLES] = no_samples
             parameters[PARAMETER_NUM_RET_ITEMS] = max_no_ret_items
             parameters["max_no_of_points_to_sample"] = max_no_ret_items
+            parameters["timestamp_key"] = timestamp_key
 
             returned_list = parquet_handler.get_events_per_time(SlaveVariableContainer.conf, process,
                                                                 SlaveVariableContainer.managed_logs[process],
